OC.L10N.register(
    "mail",
    {
    "Mail" : "電子郵件",
    "Inbox" : "收件匣",
    "Sent" : "寄件備份",
    "Drafts" : "草稿",
    "Archive" : "封存",
    "Trash" : "回收筒",
    "Junk" : "垃圾郵件",
    "All" : "所有",
    "Favorites" : "最愛",
    "Auto detect failed. Please use manual mode." : "自動偵測失敗，請改用手動輸入",
    "Updating account failed: " : "更新帳戶失敗",
    "Creating account failed: " : "建立帳號失敗：",
    "Delete permanently" : "永久刪除",
    "IMAP web client" : "IMAP客戶端",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "一個簡易的電子郵件程式，透過IMAP與SMTP功能與郵件伺服器同步",
    "Auto" : "自動",
    "Name" : "名字",
    "Mail Address" : "郵件地址",
    "Password" : "密碼",
    "Manual" : "手動",
    "IMAP Settings" : "IMAP設定",
    "IMAP Host" : "IMAP 主機",
    "IMAP Security" : "IMAP Security",
    "None" : "無",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 連接埠",
    "IMAP User" : "IMAP 帳號",
    "IMAP Password" : "IMAP 密碼",
    "SMTP Settings" : "SMTP設定",
    "SMTP Host" : "SMTP 主機",
    "SMTP Security" : "SMTP Security",
    "SMTP Port" : "SMTP 連接埠",
    "SMTP User" : "SMTP 帳號",
    "SMTP Password" : "SMTP 密碼",
    "Save" : "儲存",
    "Connect" : "連線",
    "Add mail account" : "新增郵件帳戶",
    "Use Gravatar and favicon avatars" : "使用個人化大頭貼與網站圖示",
    "Keyboard shortcuts" : "快速鍵",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "需要一個方式加密您的電子郵件嗎？請安裝 Mailvelope 瀏覽器擴充程式",
    "from" : "自",
    "to" : "至",
    "cc" : "副本",
    "bcc" : "密件副本",
    "Subject" : "主旨",
    "Sending …" : "傳送中…",
    "Message sent!" : "信件已寄出",
    "Send" : "傳送",
    "Upload attachment" : "上傳附件",
    "Add attachment from Files" : "從雲端檔案中加入附件",
    "Choose a file to add as attachment" : "選擇檔案作為附件",
    "No messages in this folder" : "此收件匣中沒有信件",
    "Delete" : "刪除",
    "Could not load your message" : "無法載入您的信件",
    "Import into calendar" : "匯入到日曆",
    "Download attachment" : "下載附檔",
    "Save to Files" : "儲存至雲端檔案",
    "Choose a folder to store the attachment in" : "選擇存放附件的目錄",
    "Save all to Files" : "全部儲存至檔案",
    "The images have been blocked to protect your privacy." : "為維護您的隱私，圖片將不會被載入",
    "New message" : "新信件",
    "Settings" : "設定",
    "Show all folders" : "顯示所有收件匣",
    "Collapse folders" : "收合收件匣",
    "Speed up your Mail experience with these quick shortcuts." : "使用快速鍵來加速您的操作體驗",
    "Compose new message" : "撰寫新信件",
    "Newer message" : "較新的信件",
    "Older message" : "較舊的信件",
    "Toggle star" : "加上/移除星號",
    "Toggle unread" : "標示未讀/已讀",
    "Search" : "搜尋",
    "Refresh" : "重整",
    "Connect your mail account" : "連結外部信箱",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n則新信件\n來自 {from}"],
    "Nextcloud Mail" : "Nextcloud 郵件",
    "All inboxes" : "所有收件匣",
    "Could not load {tag}{name}{endtag}" : "無法載入 {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "載入 {tag}{name}{endtag} 時出現問題",
    "Could not load the desired message" : "無法載入所選的信件",
    "Could not load the message" : "無法載入信件",
    "Error loading message" : "載入信件錯誤",
    "Forwarding to %s" : "正在轉寄給%s",
    "Click here if you are not automatically redirected within the next few seconds." : "如果未在幾秒內跳轉，請點擊這裡",
    "Redirect" : "跳轉",
    "The link leads to %s" : "該連結導向至 %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "若不想拜訪該頁，您可以回到<a href=\"%s\">郵件</a>",
    "Continue to %s" : "前往 %s"
},
"nplurals=1; plural=0;");
